package javax.swing.plaf.synth;

import javax.swing.JSeparator;
import java.awt.Insets;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.BorderLayout;
import javax.swing.JPanel;
import sun.swing.DefaultLookup;
import javax.swing.JOptionPane;
import java.beans.PropertyChangeEvent;
import java.awt.Graphics;
import java.awt.Container;
import javax.swing.Box;
import java.awt.Dimension;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import java.beans.PropertyChangeListener;
import javax.swing.plaf.basic.BasicOptionPaneUI;

public class SynthOptionPaneUI extends BasicOptionPaneUI implements PropertyChangeListener, SynthUI
{
    private SynthStyle style;
    
    public SynthOptionPaneUI() {
    }
    
    public static ComponentUI createUI(JComponent component) {
        return new SynthOptionPaneUI();
    }
    
    @Override
    protected void installDefaults() {
        this.updateStyle(this.optionPane);
    }
    
    @Override
    protected void installListeners() {
        super.installListeners();
        this.optionPane.addPropertyChangeListener(this);
    }
    
    private void updateStyle(JComponent component) {
        SynthContext context = this.getContext(component, 1);
        SynthStyle style = this.style;
        this.style = SynthLookAndFeel.updateStyle(context, this);
        if (this.style != style) {
            this.minimumSize = (Dimension)this.style.get(context, "OptionPane.minimumSize");
            if (this.minimumSize == null) {
                this.minimumSize = new Dimension(262, 90);
            }
            if (style != null) {
                this.uninstallKeyboardActions();
                this.installKeyboardActions();
            }
        }
        context.dispose();
    }
    
    @Override
    protected void uninstallDefaults() {
        SynthContext context = this.getContext(this.optionPane, 1);
        this.style.uninstallDefaults(context);
        context.dispose();
        this.style = null;
    }
    
    @Override
    protected void uninstallListeners() {
        super.uninstallListeners();
        this.optionPane.removePropertyChangeListener(this);
    }
    
    @Override
    protected void installComponents() {
        this.optionPane.add(this.createMessageArea());
        Container separator = this.createSeparator();
        if (separator != null) {
            this.optionPane.add(separator);
            SynthContext context = this.getContext(this.optionPane, 1);
            this.optionPane.add(Box.createVerticalStrut(context.getStyle().getInt(context, "OptionPane.separatorPadding", 6)));
            context.dispose();
        }
        this.optionPane.add(this.createButtonArea());
        this.optionPane.applyComponentOrientation(this.optionPane.getComponentOrientation());
    }
    
    @Override
    public SynthContext getContext(JComponent component) {
        return this.getContext(component, this.getComponentState(component));
    }
    
    private SynthContext getContext(JComponent component, int n) {
        return SynthContext.getContext(component, this.style, n);
    }
    
    private int getComponentState(JComponent component) {
        return SynthLookAndFeel.getComponentState(component);
    }
    
    @Override
    public void update(Graphics graphics, JComponent component) {
        SynthContext context = this.getContext(component);
        SynthLookAndFeel.update(context, graphics);
        context.getPainter().paintOptionPaneBackground(context, graphics, 0, 0, component.getWidth(), component.getHeight());
        this.paint(context, graphics);
        context.dispose();
    }
    
    @Override
    public void paint(Graphics graphics, JComponent component) {
        SynthContext context = this.getContext(component);
        this.paint(context, graphics);
        context.dispose();
    }
    
    protected void paint(SynthContext synthContext, Graphics graphics) {
    }
    
    @Override
    public void paintBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        synthContext.getPainter().paintOptionPaneBorder(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
        if (SynthLookAndFeel.shouldUpdateStyle(propertyChangeEvent)) {
            this.updateStyle((JOptionPane)propertyChangeEvent.getSource());
        }
    }
    
    @Override
    protected boolean getSizeButtonsToSameWidth() {
        return DefaultLookup.getBoolean(this.optionPane, this, "OptionPane.sameSizeButtons", true);
    }
    
    @Override
    protected Container createMessageArea() {
        JPanel top = new JPanel();
        top.setName("OptionPane.messageArea");
        top.setLayout(new BorderLayout());
        JPanel panel = new JPanel(new GridBagLayout());
        JPanel comp = new JPanel(new BorderLayout());
        panel.setName("OptionPane.body");
        comp.setName("OptionPane.realBody");
        if (this.getIcon() != null) {
            JPanel comp2 = new JPanel();
            comp2.setName("OptionPane.separator");
            comp2.setPreferredSize(new Dimension(15, 1));
            comp.add(comp2, "Before");
        }
        comp.add(panel, "Center");
        GridBagConstraints gridBagConstraints;
        Object cons = gridBagConstraints = new GridBagConstraints();
        int n = 0;
        cons.gridy = n;
        gridBagConstraints.gridx = n;
        cons.gridwidth = 0;
        cons.gridheight = 1;
        SynthContext context = this.getContext(this.optionPane, 1);
        cons.anchor = context.getStyle().getInt(context, "OptionPane.messageAnchor", 10);
        context.dispose();
        cons.insets = new Insets(0, 0, 3, 0);
        this.addMessageComponents(panel, cons, this.getMessage(), this.getMaxCharactersPerLineCount(), false);
        top.add(comp, "Center");
        this.addIcon(top);
        return top;
    }
    
    @Override
    protected Container createSeparator() {
        JSeparator separator = new JSeparator(0);
        separator.setName("OptionPane.separator");
        return separator;
    }
}
